from django.dispatch import Signal

# Sphinx does not detect the docstring for signals when using `task_failure.__doc__`,
# because this is an instance, not a class, and this does not look like a constant.
# We would then normally have to add a string right below the signal.
# This string gets picked up successfully by Sphinx, but pre-commit fails due to a
# false positive: https://github.com/pre-commit/pre-commit-hooks/issues/159
# So we use an alternative, lesser known syntax that Sphinx supports but most other
# tools (such as IDE autocompletions) don't, with `#:` comments.

#: A task has reached a final state that is not :attr:`~State.Completed`.
#:
#: This signal will be called with the related :class:`Task` instance as the `task` keyword argument.
task_failure = Signal()
